@@ -1,12 +1,6 @@
 # Copyright 2009-2011 Ram Rachum.
 # This program is distributed under the LGPL2.1 license.
 
-'''
-This module defines the `` class.
-
-See its documentation for more information.
-'''
-
 import wx
 
 from python_toolbox.wx_tools.widgets.cute_window import CuteWindow
