@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 from python_toolbox import cute_testing
@@ -13,7 +13,8 @@ def test_get_single_if_any():
            get_single_if_any('') is None
     
     assert get_single_if_any(('g',)) == get_single_if_any(['g']) == \
-           get_single_if_any({'g'}) == get_single_if_any(iter({'g'})) == \
+           get_single_if_any(set(('g'))) == \
+           get_single_if_any(iter(set(('g', )))) == \
            get_single_if_any('g') == 'g'
 
     with cute_testing.RaiseAssertor():
@@ -22,4 +23,7 @@ def test_get_single_if_any():
     with cute_testing.RaiseAssertor():
         get_single_if_any('gee')
         
-    assert get_single_if_any('gee', exception_on_multiple=None) == 'g'
\ No newline at end of file
+    assert get_single_if_any('gee', exception_on_multiple=False) == 'g'
+    assert get_single_if_any('gee', none_on_multiple=True) is None
+    assert get_single_if_any('gee', none_on_multiple=True,
+                             exception_on_multiple=False) is None
\ No newline at end of file
