@@ -136,7 +136,8 @@ def test_helpful_message_when_forgetting_parentheses():
         
 
 def test_monkeypatch_staticmethod():
-
+    if sys.version_info[:2] == (2, 6):
+        raise nose.SkipTest
     class A(EqualByIdentity):
         @staticmethod
         def my_static_method(x):
@@ -158,6 +159,8 @@ def test_monkeypatch_staticmethod():
     
     
 def test_monkeypatch_classmethod():
+    if sys.version_info[:2] == (2, 6):
+        raise nose.SkipTest
 
     class A(EqualByIdentity):
         @classmethod
@@ -186,6 +189,9 @@ def test_monkeypatch_classmethod_subclass():
     
     This is useful in Django, that uses its own `classmethod` subclass.
     '''
+    if sys.version_info[:2] == (2, 6):
+        raise nose.SkipTest
+
     class FunkyClassMethod(classmethod):
         is_funky = True
 
