@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Testing module for `nifty_collections.ordered_dict.OrderedDict`.'''
@@ -63,12 +63,16 @@ def test_index():
     
     assert ordered_dict.index('meow') == 3
     
-    with cute_testing.RaiseAssertor(KeyError):
+    with cute_testing.RaiseAssertor(ValueError):
         ordered_dict.index('Non-existing key')
         
         
-def test_reversed():
+def test_builtin_reversed():
     '''Test the `OrderedDict.__reversed__` method.'''
     
     ordered_dict = OrderedDict(((1, 'a'), (2, 'b'), (3, 'c')))
-    assert list(reversed(ordered_dict)) == [3, 2, 1]
\ No newline at end of file
+    assert list(reversed(ordered_dict)) == [3, 2, 1]    
+def test_reversed():
+    ordered_dict = OrderedDict(((1, 'a'), (2, 'b'), (3, 'c')))
+    assert ordered_dict.reversed == OrderedDict(((3, 'c'), (2, 'b'), (1, 'a')))
+    assert type(ordered_dict.reversed) is type(ordered_dict) is OrderedDict
\ No newline at end of file
