@@ -1,12 +1,6 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
-'''
-Defines the `ReasonedBool` class.
-
-See its documentation for more details.
-'''
-
 
 class ReasonedBool:
     '''
@@ -49,5 +43,4 @@ class ReasonedBool:
 
     
     def __bool__(self):
-        return self.value
-    __nonzero__ = __bool__
\ No newline at end of file
+        return self.value
\ No newline at end of file
